@@ -24,11 +24,7 @@ protected:
     void paintEvent(QPaintEvent *event) override;
 
 private:
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     void enterEvent(QEnterEvent *event) override;
-#else
-    void enterEvent(QEvent *event) override;
-#endif
     void focusInEvent(QFocusEvent *event) override;   
     void focusOutEvent(QFocusEvent *event) override;
     void leaveEvent(QEvent *event) override;
